#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.component.hearing.interfaces import IHearingManagerTarget
from onf_website.component.location.interfaces import ILocationManagerTarget
from onf_website.shared.leisure.interfaces import ILeisureManager, LEISURE_CONTENT_TYPE, ILeisureInfo, \
    ILeisureManagerFactory
from pyams_content.component.theme.interfaces import IThemesManagerTarget
from pyams_content.shared.common.interfaces import ISharedContentFactory, IManagerRestrictionsFactory
from zope.component.interfaces import ISite
from zope.lifecycleevent.interfaces import IObjectAddedEvent

# import packages
from onf_website.shared.common.security import SharedToolManagerRestrictionInfo
from onf_website.shared.leisure import Leisure
from pyams_content.shared.common.types import TypedSharedTool
from pyams_utils.adapter import adapter_config
from pyams_utils.registry import utility_config
from pyams_utils.traversing import get_parent
from pyramid.events import subscriber
from zope.interface import implementer


@implementer(ILeisureManager, ILocationManagerTarget, IHearingManagerTarget, IThemesManagerTarget)
class LeisureManager(TypedSharedTool):
    """Leisure manager class"""

    shared_content_type = LEISURE_CONTENT_TYPE

    shared_content_types_fields = ILeisureInfo


@utility_config(provides=ILeisureManagerFactory)
class LeisureManagerFactory(object):
    """Default leisure manager factory"""

    def __new__(cls):
        return LeisureManager


@adapter_config(context=ILeisureManager, provides=IManagerRestrictionsFactory)
def leisure_manager_restrictions_factory(context):
    """Leisure manager custom restrictions factory"""
    return SharedToolManagerRestrictionInfo


@adapter_config(context=ILeisureManager, provides=ISharedContentFactory)
def leisure_manager_content_factory(context):
    return Leisure


@subscriber(IObjectAddedEvent, context_selector=ILeisureManager)
def handle_added_leisure_manager(event):
    """Register leisure manager when added"""
    site = get_parent(event.newParent, ISite)
    registry = site.getSiteManager()
    if registry is not None:
        registry.registerUtility(event.object, ILeisureManager)
