(function($, globals) {

	'use strict';

	var ams = globals.MyAMS;
	globals.ONF = {

		/**
		 * Search engines management
		 */
		search: {

			updateSort: function() {
				var form = $('form[id="recherche-results"]');
				if (form.exists()) {
					var index = $(this).data('ams-sort-index');
					$('input[name="order_by"]', form).val(index);
					form.submit();
				}
			},

			updatePageLength: function() {
				var form = $('form[id="recherche-results"]');
				if (form.exists()) {
					var length = $(this).val();
					$('input[name="start"]', form).val(0);
					$('input[name="length"]', form).val(length);
					form.submit();
				}
			},

			previousPage: function() {
				var form = $('form[id="recherche-results"]');
				if (form.exists()) {
					var current = $(this).parents('ol.pagination').data('ams-current-page');
					var length = $('input[name="length"]', form).val();
					$('input[name="start"]', form).val(length * (current - 2));
					form.submit();
				}
			},

			nextPage: function() {
				var form = $('form[id="recherche-results"]');
				if (form.exists()) {
					var current = $(this).parents('ol.pagination').data('ams-current-page');
					var length = $('input[name="length"]', form).val();
					$('input[name="start"]', form).val(length * current);
					form.submit();
				}
			},

			gotoPage: function() {
				var form = $('form[id="recherche-results"]');
				if (form.exists()) {
					var target = parseInt($(this).text());
					var length = $('input[name="length"]', form).val();
					$('input[name="start"]', form).val(length * (target - 1));
					form.submit();
				}
			}
		},

		/**
		 * Forms management
		 */
		form: {

			submitHandler: function(form, event) {
				var button = $('button[type="submit"]', form);
				$('<input />').attr('type', 'hidden')
							  .attr('name', button.attr('name'))
							  .attr('value', button.attr('value'))
							  .appendTo(form);
				if (window.grecaptcha) {  // check if recaptcha was loaded
					var captcha_key = $(form).data('ams-form-captcha-key');
					grecaptcha.execute(captcha_key, {action: 'form_submit'}).then(function(token) {
						$('.state-error', form).removeClass('state-error');
						$('input[name="g-recaptcha-response"]', form).val(token);
						form.submit();
					});
				} else {
					form.submit();
				}
			}
		}
	};

	/**
	 * Update main menus status
	 */
	$('.main-nav__link', '#menu-principal').each(function() {
		if (window.location.href.startsWith($(this).attr('data-ams-url') || '##')) {
			$(this).parents('li').first().addClass('main-nav__item--current');
		}
	});

	/**
	 * Update all external links target
	 */
	var base = window.location.protocol + '//' + window.location.host;
	$('a[href]').each(function() {
		var href = $(this).attr('href');
		if (!(href.startsWith('/') ||
			  href.startsWith('#') ||
			  href.startsWith('javascript:') ||
			  href.startsWith('mailto:') ||
			  href.startsWith(base))) {
			$(this).attr('target', '_blank');
		}
	});

	/**
	 * Update SVG images
	 */
	var svgs = $('.svg-container');
	if (svgs.length > 0) {
		svgs.each(function() {
			var container = $(this);
			var svg = $('svg', container),
				width = svg.attr('width'),
				height = svg.attr('height');
			if (width && height) {
				svg.get(0).setAttribute('viewBox',
										'0 0 ' + Math.round(parseFloat(width)) + ' ' +
												 Math.round(parseFloat(height)));
			}
			svg.attr('width', '100%')
			   .attr('height', 'auto')
			   .removeAttr('preserveAspectRatio');
		})
	}

	/**
	 * Home page video player button
	 */
	var videoBg = $('#homebannerVideoBg');
	if (videoBg.length > 0) {
		var button = $('#videoBgButton');
		var buttonText = $('#videoBgButtonTxt');

		button.on('click', function (e) {
			if (buttonText.hasClass('playing')) {
				videoBg.get(0).pause();
				button.removeClass('homebanner__videoBtn--paused');
				buttonText.removeClass('playing')
						  .text(buttonText.data('onf-play-text'));
			} else {
				videoBg.get(0).play();
				button.addClass('homebanner__videoBtn--paused');
				buttonText.addClass('playing')
						  .text(buttonText.data('onf-stop-text'));
			}
		});
	}


	// Initialize main events handlers
	MyAMS.initHandlers(document);


	// Download custom MyAMS modules to handle forms
	var forms = $('form.ams-form', document);
	if (forms.exists()) {
		ams.require(['error', 'ajax', 'form', 'plugins-loader', 'helpers', 'i18n'], function () {
			var required = ['plugins'];
			var html = $('html');
			var lang = html.attr('lang') || html.attr('xml:lang');
			if (lang && !lang.startsWith('en')) {
				ams.lang = lang;
				required.push(ams.baseURL + 'i18n/myams_' + lang.substr(0, 2) + ams.devext + '.js');
			}
			ams.require(required, function() {
				ams.getCSS('/--static--/pyams_default_theme/css/select2.css', 'pyams_select2', function () {
					ams.plugins.initData(document);
					ams.form.init(document);
					ams.plugins.init(document);
				});
			});
		});
	}

})(jQuery, this);
